@@ -20,12 +20,7 @@
 
 #include "kfileitem.h"
 
-#include <pwd.h>
-#include <grp.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
-#include <unistd.h>
+#include "kioglobal_p.h"
 
 #include <QtCore/QDate>
 #include <QtCore/QDir>
@@ -44,7 +39,7 @@
 #include <knfsshare.h>
 #include <ksambashare.h>
 #endif
-#include <kfilesystemtype_p.h>
+#include <kfilesystemtype.h>
 
 class KFileItemPrivate : public QSharedData
 {
@@ -63,7 +58,6 @@ public:
           m_mimeType(),
           m_fileMode(mode),
           m_permissions(permissions),
-          m_bMarked(false),
           m_bLink(false),
           m_bIsLocalUrl(itemOrDirUrl.isLocalFile()),
           m_bMimeTypeKnown(false),
@@ -100,9 +94,8 @@ public:
     void setTime(KFileItem::FileTimes which, uint time_t_val) const;
     void setTime(KFileItem::FileTimes which, const QDateTime &val) const;
     bool cmp(const KFileItemPrivate &item) const;
-    QString user() const;
-    QString group() const;
     bool isSlow() const;
+    void stat();
 
     /**
      * Extracts the data from the UDSEntry member and updates the KFileItem
@@ -159,10 +152,6 @@ public:
      */
     mode_t m_permissions;
 
-    /**
-     * Marked : see mark()
-     */
-    bool m_bMarked: 1;
     /**
      * Whether the file is a link
      */
@@ -351,8 +340,6 @@ bool KFileItemPrivate::cmp(const KFileItemPrivate &item) const
     //qDebug() << " local" << (m_bIsLocalUrl == item.m_bIsLocalUrl);
     //qDebug() << " mode" << (m_fileMode == item.m_fileMode);
     //qDebug() << " perm" << (m_permissions == item.m_permissions);
-    //qDebug() << " UDS_USER" << (user() == item.user());
-    //qDebug() << " UDS_GROUP" << (group() == item.group());
     //qDebug() << " UDS_EXTENDED_ACL" << (m_entry.stringValue( KIO::UDSEntry::UDS_EXTENDED_ACL ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_EXTENDED_ACL ));
     //qDebug() << " UDS_ACL_STRING" << (m_entry.stringValue( KIO::UDSEntry::UDS_ACL_STRING ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_ACL_STRING ));
     //qDebug() << " UDS_DEFAULT_ACL_STRING" << (m_entry.stringValue( KIO::UDSEntry::UDS_DEFAULT_ACL_STRING ) == item.m_entry.stringValue( KIO::UDSEntry::UDS_DEFAULT_ACL_STRING ));
@@ -366,8 +353,6 @@ bool KFileItemPrivate::cmp(const KFileItemPrivate &item) const
             && m_bIsLocalUrl == item.m_bIsLocalUrl
             && m_fileMode == item.m_fileMode
             && m_permissions == item.m_permissions
-            && user() == item.user()
-            && group() == item.group()
             && m_entry.stringValue(KIO::UDSEntry::UDS_EXTENDED_ACL) == item.m_entry.stringValue(KIO::UDSEntry::UDS_EXTENDED_ACL)
             && m_entry.stringValue(KIO::UDSEntry::UDS_ACL_STRING) == item.m_entry.stringValue(KIO::UDSEntry::UDS_ACL_STRING)
             && m_entry.stringValue(KIO::UDSEntry::UDS_DEFAULT_ACL_STRING) == item.m_entry.stringValue(KIO::UDSEntry::UDS_DEFAULT_ACL_STRING)
@@ -419,7 +404,7 @@ QString KFileItemPrivate::parsePermissions(mode_t perm) const
         oxbit = '-';
     }
 
-    // Include the type in the first char like kde3 did; people are more used to seeing it,
+    // Include the type in the first char like ls does; people are more used to seeing it,
     // even though it's not really part of the permissions per se.
     if (m_bLink) {
         buffer[0] = 'l';
@@ -482,12 +467,14 @@ KFileItem::KFileItem(mode_t mode, mode_t permissions, const QUrl &url, bool dela
     : d(new KFileItemPrivate(KIO::UDSEntry(), mode, permissions,
                              url, false, delayedMimeTypes))
 {
+    d->stat();
 }
 
 KFileItem::KFileItem(const QUrl &url, const QString &mimeType, mode_t mode)
     : d(new KFileItemPrivate(KIO::UDSEntry(), mode, KFileItem::Unknown,
                              url, false, false))
 {
+    d->stat();
     d->m_bMimeTypeKnown = !mimeType.isEmpty();
     if (d->m_bMimeTypeKnown) {
         QMimeDatabase db;
@@ -521,6 +508,7 @@ void KFileItem::refresh()
     // Clearing m_entry makes it possible to detect changes in the size of the file,
     // the time information, etc.
     d->m_entry.clear();
+    d->stat(); // re-populates d->m_entry
     d->init();
 }
 
@@ -583,12 +571,7 @@ QString KFileItem::linkDest() const
 
     // If not in the KIO::UDSEntry, or if UDSEntry empty, use readlink() [if local URL]
     if (d->m_bIsLocalUrl) {
-        char buf[1000];
-        const int n = readlink(QFile::encodeName(d->m_url.adjusted(QUrl::StripTrailingSlash).toLocalFile()), buf, sizeof(buf) - 1);
-        if (n != -1) {
-            buf[ n ] = 0;
-            return QFile::decodeName(buf);
-        }
+        return QFile::symLinkTarget(d->m_url.adjusted(QUrl::StripTrailingSlash).toLocalFile());
     }
     return QString();
 }
@@ -678,18 +661,7 @@ QString KFileItem::user() const
         return QString();
     }
 
-    return d->user();
-}
-
-QString KFileItemPrivate::user() const
-{
-    QString userName = m_entry.stringValue(KIO::UDSEntry::UDS_USER);
-    if (userName.isEmpty() && m_bIsLocalUrl) {
-        QFileInfo a(m_url.adjusted(QUrl::StripTrailingSlash).toLocalFile());
-        userName = QFileInfo(a.canonicalFilePath()).owner(); // get user of the link, if it's a link
-        m_entry.insert(KIO::UDSEntry::UDS_USER, userName);
-    }
-    return userName;
+    return d->m_entry.stringValue(KIO::UDSEntry::UDS_USER);
 }
 
 QString KFileItem::group() const
@@ -698,18 +670,7 @@ QString KFileItem::group() const
         return QString();
     }
 
-    return d->group();
-}
-
-QString KFileItemPrivate::group() const
-{
-    QString groupName = m_entry.stringValue(KIO::UDSEntry::UDS_GROUP);
-    if (groupName.isEmpty() && m_bIsLocalUrl) {
-        QFileInfo a(m_url.adjusted(QUrl::StripTrailingSlash).toLocalFile());
-        groupName = QFileInfo(a.canonicalFilePath()).group(); // get group of the link, if it's a link
-        m_entry.insert(KIO::UDSEntry::UDS_GROUP, groupName);
-    }
-    return groupName;
+    return d->m_entry.stringValue(KIO::UDSEntry::UDS_GROUP);
 }
 
 bool KFileItemPrivate::isSlow() const
@@ -726,6 +687,22 @@ bool KFileItemPrivate::isSlow() const
     return m_slow == Slow;
 }
 
+// This function should only be called when:
+// - KFileItem is called with a QUrl object directly!
+// - refresh is called.
+// This is done to re-populate the UDSEntry object.
+void KFileItemPrivate::stat()
+{
+    if(m_url.isLocalFile()) {
+        QT_STATBUF buf;
+        const QString path = m_url.adjusted(QUrl::StripTrailingSlash).toLocalFile();
+        const QByteArray pathBA = QFile::encodeName(path);
+        if (QT_LSTAT(pathBA.constData(), &buf) == 0) {
+            m_entry = KIO::UDSEntry(buf, m_url.fileName());
+        }
+    }
+}
+
 bool KFileItem::isSlow() const
 {
     if (!d) {
@@ -1504,35 +1481,6 @@ KIO::UDSEntry KFileItem::entry() const
     return d->m_entry;
 }
 
-bool KFileItem::isMarked() const
-{
-    if (!d) {
-        return false;
-    }
-
-    return d->m_bMarked;
-}
-
-void KFileItem::mark()
-{
-    if (!d) {
-        qWarning() << "null item";
-        return;
-    }
-
-    d->m_bMarked = true;
-}
-
-void KFileItem::unmark()
-{
-    if (!d) {
-        qWarning() << "null item";
-        return;
-    }
-
-    d->m_bMarked = false;
-}
-
 KFileItem &KFileItem::operator=(const KFileItem &other)
 {
     d = other.d;
